A guide to creating a Risk Assessment (RA) tool
===============================================

You are seeking to develop the content of the digital RA tool for companies in
your sector, and to offer this sector-specific tool to them.

Before you start making an RA tool, it is a good idea to first give thought to
a number of matters. This will save you time, as you will not have to make many
changes later on, and it will save end-users time when using the tool in
practice. The following themes are worthy of consideration.

1. The structure and content of the RA tool in relation to the end-user:

   1. it will be an entrepreneur or someone in a company who will ultimately be
      using the RA tool. The structure of the tool should be as relevant as
      possible to the thought processes and day-to-day activities of people in
      such companies;
   2. the language in the tool should be easy to for everyone to understand. 

2. The structure of an RA tool in relation to its use. Structure refers to:

   1. the establishment of a profile in the tool. A profile determines which
      modules the user of the RA tool will deal with (because the user ticks
      certain boxes with regard to the use of the digital RA tool when he
      starts to fill it in);
   2. one company with multiple locations. This option allows profiles to be
      created for each location;
   3.  various types of module. Indicating that the status of a module is
       ‘policy module’, ‘tour module’ or ‘employee question module’ means that
       the modules do not feature where they are not needed;
   4.  modules that start with a selection question. Selection questions
       determine whether or not the content of the module applies to the
       company in question;
   5.  modules with sets of questions centred around a particular subject. A
       module may contain sub-modules.

The structure and content of the RA tool in relation to the end-user
--------------------------------------------------------------------

The structure in relation to the end-user
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Who in fact is the end-user and what does this mean for the structure of the RA
tool? It is important that you realise that the end-user thinks in terms of
his own business processes. In doing so, he thinks in his own language, which
means that he refers to things by names that are familiar and usual to him: try
to factor this in as much as possible.

Often, this differs from the practice of the person drawing up the content of
RA tools. This person, too, thinks in terms of his own work processes and uses
his own language.

The end-user is essential: he has to be able to use the RA tool for his own
purposes without any problems or difficulties in interpreting it. Some examples:

* the end-user thinks of physical work, while the expert thinks of physical load;
* the end-user thinks of working in the heat or in the cold, while the expert
  thinks of the thermal environment; 
* the expert thinks of safety and creates a module containing everything in
  that area. The end-user may think of opening and closing a shop, for example,
  and what that involves, or dealing with aggressive customers and what to do
  about them. 

It is important to structure the tool so that it is in line with the way the
average end-user thinks and acts. It makes the content recognisable, and it
makes it easier to carry out a plan of action. 

Thorough consideration of the structure will pay dividends later on, so
classify the subjects in a way that is relevant to end-users. Please note that
such classifications are usually different to how experts might normally
envisage them. The basic tool upon which you can build variations contains the
following modules. In the Content Management System (CMS) manual you will find
more information on the content and how you can use this content as a basis.

1. Every building
2. A few buildings
3. Storage room / warehouse
4. Office work
5. Delivery and removal of material
6. Physical work
7. Working on site
8. Working with customers / clients / guests
9. Noise 
10. Climate: heat, radiation, cold, outdoors
11. Vibrations
12. Hazardous substances as raw materials
13. Hazardous substances as a result of / during work
14. Heights / crawl spaces / closed spaces
15. Tools / machines / means of transport
16. In case of emergency
17. Working and resting times
18. Tasks / functions of employees
19. Unwanted behaviour of employees
20. Basic agreements concerning occupational health and safety
21. Information
22. Agreements on absence from work
23. Accidents
24. State of progress of the plan of action
25. Organisation of preventive measures

    1. Prevention duties

26. Tailor-made scheme / safety net scheme

    * Tailor-made scheme
    * Safety net scheme


The content in relation to the end-user
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Language
++++++++

The content of the tool should be easy for everyone to understand. This means
you should look carefully – keeping the end-user in mind – at the type of
language that you use. It is important to use spoken rather than written
language. The end-user has to be able to understand in an instant what is
written and to be able to respond to it. In addition, it is recommended that
sentences should be no longer than ten words. Keep the needs of the end-user in
mind! Short sentences and clear everyday language that can easily be read by
the layman will prevent the user from developing an aversion, and enable him to
draw up an inventory and use the RA tool properly.

Questions/propositions
++++++++++++++++++++++
The tool works with ‘propositions’ rather than ‘questions’. The structure of
the content of the RA tool is based on propositions. 

* A situation (the proposition) is ‘in order’ or ‘not in order’; the answer is
  either a clear ‘yes’ or ‘no’.
* If a situation (the proposition) is not in order, the subject (the
  proposition) is included in the plan of action. 

The text of the proposition in the situation given (in order or not in order)
is the same as that in the plan of action. It then becomes the situation that
is to be attained. Because a response has earlier been given to a particular
situation, the wording is familiar. 

As well as being familiar to the end-user, it also has the advantage for the
person devising the content that the situation only has to be described on one
occasion. If (statutory) changes would have to be made to the tool in the
future, then any such change will only have to be implemented once.

It is also possible to select a different option in the instrument:

* identification phase: statements/questions that can be answered ‘yes’ or ‘no’;
* evaluation phase: a statement that can be evaluated;
* plan of action phase: the same statement but in the negative.

For example, ‘the building is not free of asbestos.’

In both cases it is possible to clarify statements. For example, it may concern
an explanation of why it is important to pay attention to a topic and/or what
can be done to resolve a problem. Photographs, diagrams and links can also be
attached to each topic.

Avoid any negative statements in the propositions
+++++++++++++++++++++++++++++++++++++++++++++++++

In principle, the only possible answers to the propositions are ‘yes’ and ‘no’.
It is therefore important not to put any negative statements in the
propositions. For example: ‘there is no asbestos in the building’. In
practice, the end-user will not be sure whether his ‘yes’ or ‘no’ will be
interpreted as agreement or disagreement with the proposition, so it will not
be clear whether asbestos is present or not. Reformulating the proposition
without using a negative would result in ‘the building is free of asbestos’.
‘Yes’ – the matter is in order and will not feature in the plan of action. ‘No’
– the matter is not in order (in other words, there is asbestos present in the
building) and various situations may feature in the plan of action.


The structure of the RA tool in relation to its use
---------------------------------------------------

This section deals with:

1. establishing a profile in the tool. A profile determines which modules the
   user of the RA tool will deal with (because the user answers certain
   questions at the start of the digital RA tool);
2. being able to indicate multiple locations for one company. This option
   allows profiles to be created for each location;
3. the various types of module. Indicating that the status of a module is
   ‘policy module’, ‘tour module’ or ‘employee question module’ means that the
   modules feature in the locations where they are required;
4. modules that start with a filter question. Filter questions determine
   whether the content of the module applies to the company in question;
5. modules with sets of questions centred around a particular subject. A module
   may contain sub-modules.


The profile
~~~~~~~~~~~

When using a profile question, you examine various aspects of companies and the activities in which they may be involved. The end-user of the tool answers a number of questions before actually applying the RA tool. The answers to these questions determine which modules the end-user will and which modules he will not be dealing with. An example from the fish retail trade.

* Do you have a shop?
* Do you have a stall on a market?
* Do you have a mobile sales vehicle?

Similar situations may occur in the sector where you work. It may also be the case that some of the companies transport their goods to their clients themselves, while others contract such activities out to third parties. Working out in advance whether a profile is relevant means that the end-user does not have to deal with modules that do not apply to his company.

One company with multiple locations
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
If a feature of an industry is that companies have multiple locations, then it
is sensible to indicate this in the instrument beforehand. By referring to the
locations by name (location A, location B), the end-user can then group
together his location-based RA in one RA.

For each location, the end-user can state what activities are carried out by
answering profile questions. Only the modules that apply to each location will
then be shown.

Various types of module
~~~~~~~~~~~~~~~~~~~~~~~
There are three types of module:

1. modules with desk questions
2. modules with tour questions
3. modules with employee questions

Modules with desk questions
+++++++++++++++++++++++++++
Desk questions deal with ‘basic agreements’. An example of a desk question
could be, ‘When materials are being purchased, is attention paid to
occupational health and safety requirements?’ This type of question can be
answered from behind a desk, as it were. If a company has multiple locations,
it is possible to stipulate that questions of this kind (under the heading
‘Basic agreements concerning occupational health and safety’, for example) only
have to be answered once by the company, at its head office.

Modules with tour questions
+++++++++++++++++++++++++++
These modules contain questions relating to actual risks, and are linked to the
work that is being carried out. In order to be able to answer the questions in
these modules, it is often necessary to examine the workplace. Examples of this
type of module are Physical Work and Office Work. In the case of companies
with multiple locations, profile questions can be used to establish what kind
of work is carried out in each one. For example, if one such location does not
have a warehouse, then the module dealing with warehouses will not feature at
that location.

Modules with employer questions
+++++++++++++++++++++++++++++++
This type of module is entirely different to those described previously. It is
possible to indicate in the RA tool that questions should be put specifically
to employees in cases where they are exposed to major risks. Their answers can
be used as input for the purpose of making a good-quality RA. As this type of
module is different from the others, it does not feature in the regular series
of modules. Instead, it appears before the inventory begins.

Modules with desk questions and tour questions include a general description of
what they contain. As soon as the end-user starts answering the questions, the
content will be instantly recognisable.

Filter questions
~~~~~~~~~~~~~~~~
A filter question is the first question in a module. The question determines
whether a situation is relevant. If the answer to the question is ‘no’, then
the subsequent questions in the module are not displayed. Modules with filter
questions can also be useful in certain situations. An example of a filter
question is, ‘there is a warehouse or storage area present’. This prevents the
end-user from having to answer questions in modules that are not relevant to
his company.

It is possible to work with both profile questions and filter questions. 

Main modules and sub-modules
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Another way of providing structure is to use main modules that contain
sub-modules. What matters is that you make it is easy for the end-user to
complete the RA. You can start the sub-modules with a filter question for the
purpose of determining whether the sub-module is relevant.

For example::

  Main module:                              Building
    Sub-module:                             Every building and questions regarding the building
    Sub-module:                             Some buildings
    Starting with a filter question:        The public is received in the building and questions 
                                            regarding receiving public
    Sub-module:                             Some buildings
    Starting with a filter question:        There are stairways, escalators, lifts in the building 
                                            and questions regarding those subjects
    Sub-module:                             Some buildings
    Sub-module with a filter question:      There are kitchens present in the building and questions 
                                            regarding this subject


Finally
-------

You have gained an idea of how you can construct the content of the digital RA
tool. By focusing on the possible structure: 

* in a way that is relevant to how the end-user thinks and acts; 
* and at the same time including all the subjects that, from an occupational
  health point of view, should feature in the structure and in such a way that
  the end-user can readily understand and relate to them, 

you will help the end-user complete the digital RA tool. 

The digital RA tool can be used for other purposes too, such as for providing
more detailed explanatory information and solutions, links to websites, or for
adding photographs.  To find out more about these additional uses, please refer
to the CMS (Content Management System) manual.
